@@ -164,15 +164,15 @@ public:
 	Buffer *CurrentBuffer() noexcept;
 	const Buffer *CurrentBufferConst() const noexcept;
 	void SetCurrent(BufferIndex index) noexcept;
-	BufferIndex StackNext();
-	BufferIndex StackPrev();
+	BufferIndex StackNext() noexcept;
+	BufferIndex StackPrev() noexcept;
 	void CommitStackSelection();
 	void MoveToStackTop(BufferIndex index);
 	void ShiftTo(BufferIndex indexFrom, BufferIndex indexTo);
 	void Swap(BufferIndex indexA, BufferIndex indexB);
 	bool SingleBuffer() const noexcept;
 	BackgroundActivities CountBackgroundActivities() const;
-	bool SavingInBackground() const;
+	bool SavingInBackground() const noexcept;
 	bool GetVisible(BufferIndex index) const noexcept;
 	void SetVisible(BufferIndex index, bool visible);
 private:
@@ -219,13 +219,17 @@ enum class IndentationStatus {
 	keyWordStart	// Keywords that cause indentation
 };
 
-struct StyleAndWords {
-	int styleNumber;
-	std::string words;
-	StyleAndWords() noexcept : styleNumber(0) {
-	}
-	bool IsEmpty() const noexcept { return words.length() == 0; }
-	bool IsSingleChar() const noexcept { return words.length() == 1; }
+class StyleAndWords {
+	int styleNumber = 0;
+	std::set<std::string> words;
+public:
+	StyleAndWords() noexcept;
+	explicit StyleAndWords(const std::string &definition);
+	[[nodiscard]] bool IsEmpty() const noexcept;
+	[[nodiscard]] bool IsSingleChar() const noexcept;
+	[[nodiscard]] bool IsCharacter(char ch) const noexcept;
+	[[nodiscard]] int Style() const noexcept;
+	[[nodiscard]] bool Includes(const std::string &value) const;
 };
 
 struct CurrentWordHighlight {
@@ -442,8 +446,8 @@ protected:
 	std::string wordCharacters;
 	std::string whitespaceCharacters;
 	SA::Position startCalltipWord;
-	int currentCallTip;
-	int maxCallTips;
+	ptrdiff_t currentCallTip;
+	ptrdiff_t maxCallTips;
 	std::string currentCallTipWord;
 	SA::Position lastPosCallTip;
 
@@ -534,8 +538,8 @@ protected:
 	virtual SystemAppearance CurrentAppearance() const noexcept;
 	void CheckAppearanceChanged();
 	void SetPaneFocus(bool editPane) noexcept;
-	GUI::ScintillaWindow &PaneFocused();
-	GUI::ScintillaWindow &PaneSource(int destination);
+	GUI::ScintillaWindow &PaneFocused() noexcept;
+	GUI::ScintillaWindow &PaneSource(int destination) noexcept;
 	intptr_t CallFocusedElseDefault(int defaultValue, SA::Message msg, uintptr_t wParam = 0, intptr_t lParam = 0);
 	void CallChildren(SA::Message msg, uintptr_t wParam = 0, intptr_t lParam = 0);
 	std::string GetTranslationToAbout(const char *const propname, bool retainIfNotFound = true);
@@ -702,7 +706,7 @@ protected:
 	virtual void FindIncrement() = 0;
 	int IncrementSearchMode();
 	virtual void Filter() = 0;
-	virtual bool FilterShowing() { return false; }
+	virtual bool FilterShowing() noexcept { return false; }
 	int FilterSearch();
 	virtual void FindInFiles() = 0;
 	virtual void Replace() = 0;
@@ -837,7 +841,7 @@ protected:
 
 	void RemoveToolsMenu();
 	void SetMenuItemLocalised(int menuNumber, int position, int itemID,
-				  const char *text, const char *mnemonic);
+				  std::string_view text, std::string_view mnemonic);
 	bool ToolIsImmediate(int item);
 	void SetToolsMenu();
 	JobSubsystem SubsystemType(const char *cmd);
@@ -860,7 +864,6 @@ protected:
 	StyleAndWords GetStyleAndWords(const char *base);
 	std::string ExtensionFileName() const;
 	void SetElementColour(SA::Element element, const char *key);
-	static const char *GetNextPropItem(const char *pStart, char *pPropItem, size_t maxLen) noexcept;
 	void ForwardPropertyToEditor(const char *key);
 	struct MarkerAppearance {
 		SA::ColourAlpha fore;
@@ -908,7 +911,7 @@ protected:
 	bool StartMacroList(const char *words);
 	void ContinueMacroList(const char *stext);
 	bool ProcessCommandLine(const std::vector<GUI::gui_string> &args, int phase);
-	virtual bool IsStdinBlocked();
+	virtual bool IsStdinBlocked() noexcept;
 	void OpenFromStdin(bool UseOutputPane);
 	void OpenFilesFromStdin();
 	virtual bool GrepIntoDirectory(const FilePath &directory);
@@ -936,9 +939,9 @@ protected:
 	SA::ScintillaCall &PaneCaller(Pane p) noexcept override;
 
 	// Valid CurrentWord characters
-	bool iswordcharforsel(char ch);
-	bool isfilenamecharforsel(char ch);
-	bool islexerwordcharforsel(char ch);
+	bool iswordcharforsel(char ch) noexcept;
+	bool isfilenamecharforsel(char ch) noexcept;
+	bool islexerwordcharforsel(char ch) noexcept;
 
 	CurrentWordHighlight currentWordHighlight;
 	void HighlightCurrentWord(bool highlight);
