@@ -279,13 +279,13 @@ void BufferList::PopStack() {
 	}
 }
 
-BufferIndex BufferList::StackNext() {
+BufferIndex BufferList::StackNext() noexcept {
 	if (++stackcurrent >= length)
 		stackcurrent = 0;
 	return stack[stackcurrent];
 }
 
-BufferIndex BufferList::StackPrev() {
+BufferIndex BufferList::StackPrev() noexcept {
 	if (--stackcurrent < 0)
 		stackcurrent = length - 1;
 	return stack[stackcurrent];
@@ -376,7 +376,7 @@ BackgroundActivities BufferList::CountBackgroundActivities() const {
 	return bg;
 }
 
-bool BufferList::SavingInBackground() const {
+bool BufferList::SavingInBackground() const noexcept {
 	for (int i = 0; i<length; i++) {
 		if (buffers[i].pFileWorker && !buffers[i].pFileWorker->IsLoading() && !buffers[i].pFileWorker->FinishedJob()) {
 			return true;
@@ -712,7 +712,7 @@ void SciTEBase::RestoreSession() {
 		bufferState.file.Set(GUI::StringFromUTF8(propStr));
 
 		propKey = IndexPropKey("buffer", i, "current");
-		if (propsSession.GetInt(propKey.c_str()))
+		if (propsSession.GetInt(propKey))
 			session.pathActive = bufferState.file;
 
 		propKey = IndexPropKey("buffer", i, "scroll");
@@ -1480,8 +1480,8 @@ void SciTEBase::RemoveToolsMenu() {
 }
 
 void SciTEBase::SetMenuItemLocalised(int menuNumber, int position, int itemID,
-				     const char *text, const char *mnemonic) {
-	GUI::gui_string localised = localiser.Text(text);
+				     std::string_view text, std::string_view mnemonic) {
+	const GUI::gui_string localised = localiser.Text(text);
 	SetMenuItem(menuNumber, position, itemID, localised.c_str(), GUI::StringFromUTF8(mnemonic).c_str());
 }
 
@@ -1494,7 +1494,7 @@ bool SciTEBase::ToolIsImmediate(int item) {
 
 	const std::string_view command = props.GetWild(propName, FileNameExt().AsUTF8());
 	if (command.length()) {
-		JobMode jobMode(props, item, FileNameExt().AsUTF8().c_str());
+		JobMode jobMode(props, item, FileNameExt().AsUTF8());
 		return jobMode.jobType == JobSubsystem::immediate;
 	}
 	return false;
@@ -1506,23 +1506,18 @@ void SciTEBase::SetToolsMenu() {
 	RemoveToolsMenu();
 	int menuPos = TOOLS_START;
 	for (int item = 0; item < toolMax; item++) {
-		const int itemID = IDM_TOOLS + item;
-		std::string prefix = "command.name.";
-		prefix += StdStringFromInteger(item);
-		prefix += ".";
-		std::string commandName = props.GetNewExpandString(prefix, FileNameExt().AsUTF8());
-		if (commandName.length()) {
-			std::string sMenuItem = commandName;
-			prefix = "command.shortcut.";
-			prefix += StdStringFromInteger(item);
-			prefix += ".";
-			std::string sMnemonic = props.GetNewExpandString(prefix, FileNameExt().AsUTF8());
-			if (item < 10 && sMnemonic.length() == 0) {
-				sMnemonic += "Ctrl+";
-				sMnemonic += StdStringFromInteger(item);
+		const std::string itemText = StdStringFromInteger(item);
+		const std::string itemSuffix = itemText + ".";
+		const std::string commandNamePrefix = "command.name." + itemSuffix;
+		const std::string commandName = props.GetNewExpandString(commandNamePrefix, FileNameExt().AsUTF8());
+		if (!commandName.empty()) {
+			const std::string shortcutPrefix = "command.shortcut." + itemSuffix;
+			std::string sMnemonic = props.GetNewExpandString(shortcutPrefix, FileNameExt().AsUTF8());
+			if (item < 10 && sMnemonic.empty()) {
+				sMnemonic = "Ctrl+" + itemText;
 			}
-			SetMenuItemLocalised(menuTools, menuPos, itemID, sMenuItem.c_str(),
-					     sMnemonic.length() ? sMnemonic.c_str() : nullptr);
+			const int itemID = IDM_TOOLS + item;
+			SetMenuItemLocalised(menuTools, menuPos, itemID, commandName, sMnemonic);
 			menuPos++;
 		}
 	}
@@ -1558,7 +1553,7 @@ void SciTEBase::ToolsMenu(int item) {
 	const std::string propName = std::string("command.") + itemSuffix;
 	std::string command(props.GetWild(propName, FileNameExt().AsUTF8()));
 	if (command.length()) {
-		JobMode jobMode(props, item, FileNameExt().AsUTF8().c_str());
+		JobMode jobMode(props, item, FileNameExt().AsUTF8());
 		if (jobQueue.IsExecuting() && (jobMode.jobType != JobSubsystem::immediate))
 			// Busy running a tool and running a second can cause failures.
 			return;
@@ -1911,6 +1906,14 @@ static SA::Line DecodeMessage(const char *cdoc, std::string &sourcePath, int for
 			break;
 		}
 
+	case SCE_ERR_BASH: {
+			const char *bashDiagnosticMark = ": line ";
+			const char *line = strstr(cdoc, bashDiagnosticMark);
+			sourcePath.assign(cdoc, line);
+			const SA::Line sourceNumber = IntegerFromText(line + strlen(bashDiagnosticMark)) - 1;
+			return sourceNumber;
+		}
+
 	case SCE_ERR_DIFF_MESSAGE: {
 			// Diff file header, either +++ <filename> or --- <filename>, may be followed by \t
 			// Often followed by a position line @@ <linenumber>
