@@ -264,7 +264,7 @@ SciTEWin::~SciTEWin() {
 		// Show debugger in this case.
 		assert(!buffer.doc);
 		// Drop ownership, leads to leak but exiting anyway.
-		buffer.doc.release();
+		std::ignore = buffer.doc.release();
 	}
 
 	if (hDevMode)
@@ -473,8 +473,8 @@ void SciTEWin::ReadEmbeddedProperties() {
 		if (hmem) {
 			const void *pv = ::LockResource(hmem);
 			if (pv) {
-				propsEmbed.ReadFromMemory(
-					static_cast<const char *>(pv), size, FilePath(), filter, nullptr, 0);
+				propsEmbed.ReadFromMemory(std::string_view(static_cast<const char *>(pv), size),
+					FilePath(), filter, nullptr, 0);
 			}
 		}
 		::FreeResource(handProps);
@@ -1478,17 +1478,13 @@ void SciTEWin::CreateUI() {
 		RestorePosition();
 
 	LocaliseMenus();
-	std::string pageSetup = props.GetString("print.margins");
-	char val[32] = "";
-	const char *ps = pageSetup.c_str();
-	const char *next = GetNextPropItem(ps, val, 32);
-	pagesetupMargin.left = atol(val);
-	next = GetNextPropItem(next, val, 32);
-	pagesetupMargin.right = atol(val);
-	next = GetNextPropItem(next, val, 32);
-	pagesetupMargin.top = atol(val);
-	GetNextPropItem(next, val, 32);
-	pagesetupMargin.bottom = atol(val);
+	std::vector<std::string> printMargins = StringSplit(
+		props.GetString("print.margins"), ',');
+	printMargins.resize(4); // Ensure indexing won't fail
+	pagesetupMargin.left = IntegerFromString(printMargins[0], 0);
+	pagesetupMargin.right = IntegerFromString(printMargins[1], 0);
+	pagesetupMargin.top = IntegerFromString(printMargins[2], 0);
+	pagesetupMargin.bottom = IntegerFromString(printMargins[3], 0);
 
 	UIAvailable();
 }
@@ -1783,7 +1779,7 @@ bool SciTEWin::PreOpenCheck(const GUI::gui_string &file) {
 	- the pipe cannot be peeked, which appears to be from command lines such as "scite <file.txt"
 	otherwise it is unblocked
 */
-bool SciTEWin::IsStdinBlocked() {
+bool SciTEWin::IsStdinBlocked() noexcept {
 	DWORD unreadMessages = 0;
 	INPUT_RECORD irec[1] = {};
 	char bytebuffer = '\0';
